#include "iniparser.h"

#include <iostream>
using namespace std;

int IniFile::ReadFile(const char* filename) {
	int count = 0;
	
	FILE* fin = fopen(filename, "r");
	
	if (fin == NULL) return 0;
	
	while (!feof(fin)) {
		char data[1000];
		
		fgets(data, 1000, fin);
		
		string key, val;
		
		int idx = -1;
		for(unsigned int i=0; i < strlen(data); i++) {
			if (data[i] == '=')
				idx = i;
		}
		
		if (idx == -1) 
			continue;
			
		data[strlen(data)-1] = '\0';  // remove newline
		data[idx] = '\0';
		
		key = data;
		val = &data[idx+1];
		
		IniValues[key] = val;

		#ifdef DEBUG
		printf("read: %s - %s\n", key.c_str(), val.c_str() );
		printf("check: %s - %s\n", key.c_str(), IniValues[key].c_str() );
		#endif

		count++;
	}
	
	fclose(fin);
	return count;
}

int IniFile::WriteFile(char* filename) {
	FILE* fout;
	map<string,string>::iterator it;
	int count=0;
	fout =fopen(filename,"w");
	
	if (fout == NULL)     // fail to open - possibly out of space, or read only
	   return 0;
	
	for(it=IniValues.begin(); it!=IniValues.end(); it++) {
		string key,val;
		key = (*it).first;
		val = (*it).second;

		#ifdef DEBUG
		printf("%s=%s\n", key.c_str(), val.c_str() );
		#endif

		fprintf(fout,"%s=%s\n", key.c_str(), val.c_str() );
		count++;
	}
	
	fclose(fout);
//	printf("test\n");
	return count;
}

string IniFile::GetValue(string key) {
	map<string,string>::iterator it;
	it = IniValues.find(key);
	
	if (it == IniValues.end() )
		return "";

	return it->second;
}

void IniFile::SetValue(string key, string val) {
	IniValues[key] = val;
}

bool IniFile::GetBooleanValue(string key, bool defaultValue) {
    string val = GetValue(key);
    
    if (val.length() == 0)
        return defaultValue;
        
//    val = val.toLower();
    val[0] |= 0x20;

    if (val.at(0) == 't')
        return true;
    
    if (val.at(0) == 'f')
        return false;
        
    return defaultValue;
}

void IniFile::SetBooleanValue(string key, bool val) {
    if (val)
        SetValue(key, "true");
    else
        SetValue(key, "false");   
}

int IniFile::GetIntegerValue(string key, int defaultValue) {
    string val = GetValue(key);
    return atoi(val.c_str() );
}

void IniFile::SetIntegerValue(string key, int val) {
    char buffer[100];
    sprintf(buffer, "%d", val);
    SetValue(key, buffer);   
}

float IniFile::GetFloatValue(string key, float defaultValue) {
    string val = GetValue(key);
    return atof(val.c_str() );
}

void IniFile::SetFloatValue(string key, float val) {
    char buffer[100];
    sprintf(buffer, "%f", val);
    SetValue(key, buffer);
}
